; ##############################################################################
; ##############################################################################
; ##############################################################################
; Bit 	D7 	D6 	D5 	D4 	D3 		D2 		D1 	D0									
;STATUS CTS	ERR X 	X 	RSQINT 	RDSINT 	X 	STCINT								
; Bit7 CTS 		= Clear to Send. 0 = Wait before sending next command. 1 = Clear to send next command.
; Bit6 ERR 		= Error. 0 = No error 1 = Error														
; Bit3 RSQINT 	= Received Signal Quality Interrupt. 0 = Received Signal Quality measurement has not been triggered.1 = Received Signal Quality measurement has been triggered.
; Bit2 RDSINT 	= Radio Data System (RDS) Interrupt. 0 = Radio data system interrupt has not been triggered.1 = Radio data system interrupt has been triggered.
; Bit0 STCINT 	= Seek/Tune Complete Interrupt. 0 = Tune complete has not been triggered. 1 = Tune complete has been triggered.
SI4735_GET_INT_STATUS:
	ldi temp1,(TWI_ADRESSE_RADIO)
	rcall TWI_MASTER_TRANSMITTER_START_TEMP1	; MT-START	
	ldi temp1,(GET_INT_STATUS)
	rcall TWI_MASTER_TRANSMITTER_TEMP1			; CMD		
	rcall TWI_STOP								; STOPP		
;-------------------------------------------------------------------------------
	ldi temp1,(TWI_ADRESSE_RADIO)
	rcall TWI_MASTER_RECEIVER_START_TEMP1		; MR-START	
	rcall TWI_MASTER_RECEIVER_NO_ACK_TEMP1		; STATUS	
	STS(adr_STATUS),temp1

	rcall TWI_STOP								; STOPP		
;-------------------------------------------------------------------------------
	; ERROR		
	LDS temp,(adr_STATUS)
	andi temp,0b01000000
	tst temp
	brne SI4735_GET_INT_STATUS_ERROR
	ret
SI4735_GET_INT_STATUS_ERROR:
	ldi temp,(ERROR_INT_STATUS)
	STS(adr_ERROR_CODE),temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SI4735_INT_STATUS_WAIT:
	rcall SI4735_GET_INT_STATUS
	LDS temp,(adr_STATUS)
	andi temp,0x80
	tst temp
	breq SI4735_INT_STATUS_WAIT
SI4735_INT_STATUS_WAIT_OK:
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; CMD  0 0 0 1 0 0 1 0															
; ARG1 0 0 0 0 0 0 0 0															
; ARG2 Property High Byte.		(temp2)											
; ARG3 Property Low Byte.		(temp1)											
; ARG4 Property Value High Byte.(temp4)											
; ARG5 Property Value Low Byte.	(temp3)											
SI4735_SET_PROPERTY_TEMP1_4:
	; sichern im SRAM			
	STS(adr_PROPERTY_L),temp1		;Property Low Byte			
	STS(adr_PROPERTY_H),temp2		;Property High Byte			
	STS(adr_PROPERTY_VALUE_L),temp3	;Property Value Low Byte	
	STS(adr_PROPERTY_VALUE_H),temp4	;Property Value High Byte	



	ldi temp1,(TWI_ADRESSE_RADIO)
	rcall TWI_MASTER_TRANSMITTER_START_TEMP1	; MT-START	
	ldi temp1,(SET_PROPERTY)
	rcall TWI_MASTER_TRANSMITTER_TEMP1			; CMD		
	ldi temp1,0			; NULL
	rcall TWI_MASTER_TRANSMITTER_TEMP1			; ARG 1		

	LDS temp1,(adr_PROPERTY_H)			;Property High Byte
	rcall TWI_MASTER_TRANSMITTER_TEMP1
	LDS temp1,(adr_PROPERTY_L)			;Property Low Byte
	rcall TWI_MASTER_TRANSMITTER_TEMP1
	LDS temp1,(adr_PROPERTY_VALUE_H)	;Property Value High Byte
	rcall TWI_MASTER_TRANSMITTER_TEMP1
	LDS temp1,(adr_PROPERTY_VALUE_L)	;Property Value Low Byte
	rcall TWI_MASTER_TRANSMITTER_TEMP1

	rcall TWI_STOP								; STOPP		

	rcall SI4735_INT_STATUS_WAIT				; wait...

ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; CMD  0 0 0 1 0 0 1 0															
; ARG1 0 0 0 0 0 0 0 0															
; ARG2 Property High Byte.		(temp2)											
; ARG3 Property Low Byte.		(temp1)											
;																				
;Response:																		
; Bit 		D7 	D6 	D5 	D4 	D3 		D2 		D1 	D0								
; STATUS 	CTS ERR X 	X 	RSQINT 	RDSINT 	X 	STCINT							
; RESP1 	0 	0 	0 	0 	0 		0 		0 	0								
; RESP2 	Property Value High Byte.	(temp4)											
; RESP3 	Property Value Low Byte.	(temp3)											
SI4735_GET_PROPERTY_TEMP1_4:
	STS(adr_PROPERTY_H),temp2	;Property High Byte
	STS(adr_PROPERTY_L),temp1	;Property Low Byte



	ldi temp1,(TWI_ADRESSE_RADIO)
	rcall TWI_MASTER_TRANSMITTER_START_TEMP1	; MT-START	
	ldi temp1,(GET_PROPERTY)
	rcall TWI_MASTER_TRANSMITTER_TEMP1			; CMD		
	ldi temp1,0			; NULL
	rcall TWI_MASTER_TRANSMITTER_TEMP1			; ARG 1		

	LDS temp1,(adr_PROPERTY_H)			;Property High Byte
	rcall TWI_MASTER_TRANSMITTER_TEMP1
	LDS temp1,(adr_PROPERTY_L)			;Property Low Byte
	rcall TWI_MASTER_TRANSMITTER_TEMP1

	rcall TWI_STOP								; STOPP		
;-------------------------------------------------------------------------------
	ldi temp1,(TWI_ADRESSE_RADIO)
	rcall TWI_MASTER_RECEIVER_START_TEMP1		; MR-START	

	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; STATUS	
	STS(adr_STATUS),temp1				; STATUS	
	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; RESP1		
										; DUMMY
	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; RESP2		
	STS(adr_PROPERTY_VALUE_H),temp1		;Property Value High Byte.	(temp4)
	rcall TWI_MASTER_RECEIVER_NO_ACK_TEMP1		; RESP3		
	STS(adr_PROPERTY_VALUE_L),temp1		;Property Value Low Byte.	(temp3)

	rcall TWI_STOP								; STOPP		

	LDS temp3,(adr_PROPERTY_H)			;Property High Byte			
	LDS temp3,(adr_PROPERTY_L)			;Property Low Byte			
	LDS temp3,(adr_PROPERTY_VALUE_L)	;Property Value Low Byte	
	LDS temp4,(adr_PROPERTY_VALUE_H)	;Property Value High Byte	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; RESP1 7:0 PN[7:0] Final 2 digits of Part Number (HEX).						
; RESP2 7:0 FWMAJOR[7:0] Firmware Major Revision (ASCII).						
; RESP3 7:0 FWMINOR[7:0] Firmware Minor Revision (ASCII).						
; RESP4 7:0 PATCHH[7:0] Patch ID High Byte (HEX).								
; RESP5 7:0 PATCHL[7:0] Patch ID Low Byte (HEX).								
; RESP6 7:0 CMPMAJOR[7:0] Component Major Revision (ASCII). 					
; RESP7 7:0 CMPMINOR[7:0] Component Minor Revision (ASCII). 					
; RESP8 7:0 CHIPREV[7:0] Chip Revision (ASCII).									
; RESP15 7:0 CID[7:0] CID (Si4705/06 only).										
SI4735_GET_REV:
	ldi temp1,(TWI_ADRESSE_RADIO)
	rcall TWI_MASTER_TRANSMITTER_START_TEMP1	; MT-START	
	ldi temp1,(GET_REV)
	rcall TWI_MASTER_TRANSMITTER_TEMP1			; CMD		
	rcall TWI_STOP								; STOPP		
;-------------------------------------------------------------------------------
	ldi temp1,(TWI_ADRESSE_RADIO)
	rcall TWI_MASTER_RECEIVER_START_TEMP1		; MR-START	

	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; STATUS	
	STS(adr_STATUS),temp1
	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; RESP1		
	STS(adr_RESP_01),temp1
	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; RESP2		
	STS(adr_RESP_02),temp1
	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; RESP3		
	STS(adr_RESP_03),temp1
	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; RESP4		
	STS(adr_RESP_04),temp1
	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; RESP5		
	STS(adr_RESP_05),temp1
	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; RESP6		
	STS(adr_RESP_06),temp1
	rcall TWI_MASTER_RECEIVER_ACK_TEMP1			; RESP7		
	STS(adr_RESP_07),temp1
	rcall TWI_MASTER_RECEIVER_NO_ACK_TEMP1		; RESP8		
	STS(adr_RESP_08),temp1

	rcall TWI_STOP								; STOPP		

ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SI4735_POWER_DOWN:
	ldi temp1,(TWI_ADRESSE_RADIO)
	rcall TWI_MASTER_TRANSMITTER_START_TEMP1	; MT-START	
	
	ldi temp1,(POWER_DOWN)
	rcall TWI_MASTER_TRANSMITTER_TEMP1			; CMD		

	rcall TWI_STOP								; STOPP		

	rcall wait_1s
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SI4735_RX_VOLUME_WRITE:
	ldi temp1,LOW (RX_VOLUME)			;Property Low Byte			
	ldi temp2,HIGH(RX_VOLUME)			;Property High Byte			
	ldi temp3,LOW (30)					;Property Value Low Byte	
	ldi temp4,HIGH(30)					;Property Value High Byte	
	rcall SI4735_SET_PROPERTY_TEMP1_4
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SI4735_RX_VOLUME_READ:
	ldi temp1,LOW (RX_VOLUME)			;Property Low Byte
	ldi temp2,HIGH(RX_VOLUME)			;Property High Byte
	rcall SI4735_GET_PROPERTY_TEMP1_4
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
